.. -*- mode: rst; fill-column: 78; indent-tabs-mode: nil -*-
.. vi: set ft=rst sts=4 ts=4 sw=4 et tw=79:
  ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ###
  #
  #   See COPYING file distributed along with the PyMVPA package for the
  #   copyright and license terms.
  #
  ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ###

.. index:: Dataset Database

.. _chap_datadb:

****************
Dataset Database
****************

Provided collection of datasets is not aiming to replace other data
repositories available online.  Rather it is a selection of datasets which was
repeatedly analyzed by PyMVPA team and found to be useful for demonstration of
concrete analysis methodologies especially in the context of neural data
analysis.

.. toctree::
   :maxdepth: 1

   datadb/tutorial_data
   datadb/face_inversion_demo
   datadb/haxby2001
   datadb/mnist
   datadb/hyperalignment_tutorial_data

==========================
External Data Repositories
==========================

Repositories containing generic datasets in the realm of :term:`Machine
Learning`:

* `UC Irvine Machine Learning Repository`_


Neural data repositories:

* `OpenFMRI`_
* `NITRC Image Repository`_
* `fMRI Data Center`_
* `1000 Functional Connectomes`_
* `Test-Retest Resting State Data`_ (Shehzad, Kelly et al. (2009))

.. _OpenfMRI: https://openfmri.org/
.. _NITRC Image Repository: http://www.nitrc.org/ir/
.. _UC Irvine Machine Learning Repository: http://archive.ics.uci.edu/ml/
.. _fMRI Data Center: http://www.fmridc.org
.. _1000 Functional Connectomes: http://www.nitrc.org/projects/fcon_1000/
.. _Test-Retest Resting State Data: http://www.nitrc.org/frs/?group_id=274
